==> haskell-modern-uri-0.3.4.1-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 modern-uri
version:              0.3.4.1
visibility:           public
id:                   modern-uri-0.3.4.1-FQaaETd99McJIWT0S3KU1W
key:                  modern-uri-0.3.4.1-FQaaETd99McJIWT0S3KU1W
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  ba9508bb95d06ac883aa58ab9f1dd73d
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/modern-uri-0.3.4.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/modern-uri-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/modern-uri-0.3.4.1
hs-libraries:         HSmodern-uri-0.3.4.1-FQaaETd99McJIWT0S3KU1W
depends:
    QuickCheck-2.14.2-IrhINHdHXv9CDSLhYN7ABW base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A deepseq-1.4.5.0
    exceptions-0.10.4 megaparsec-9.1.0-9h7Zz4fmExcEvijmO65kCJ mtl-2.2.2
    profunctors-5.6.2-GeLeHRNJfAL7PENADICrie
    reflection-2.1.6-4d6iwlHPb428q1oO1HEWIf
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 template-haskell-2.17.0.0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-modern-uri-0.3.4.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 modern-uri
version:              0.3.4.1
visibility:           public
id:                   modern-uri-0.3.4.1-LZ5V4Ds1Iw64OMK73SSUbO
key:                  modern-uri-0.3.4.1-LZ5V4Ds1Iw64OMK73SSUbO
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  049a51bc1edcd47d4201c5244c1930bd
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/modern-uri-0.3.4.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/modern-uri-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/modern-uri-0.3.4.1
hs-libraries:         HSmodern-uri-0.3.4.1-LZ5V4Ds1Iw64OMK73SSUbO
depends:
    QuickCheck-2.14.2-IrhINHdHXv9CDSLhYN7ABW base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1
    contravariant-1.5.5-1Tz7FaRP9yoKqkcBKkQ76A deepseq-1.4.5.0
    exceptions-0.10.4 megaparsec-9.1.0-9h7Zz4fmExcEvijmO65kCJ mtl-2.2.2
    profunctors-5.6.2-CF3PcQXMvphBHa5d1pY16G
    reflection-2.1.6-4d6iwlHPb428q1oO1HEWIf
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25 template-haskell-2.17.0.0
    text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
